Subject: Re: CVS commit: syssrc
To: None <jhawk@MIT.EDU>
From: Masanori Kanaoka <kanaoka@ann.hi-ho.ne.jp>
List: source-changes
Date: 04/19/2001 17:40:58
Hi,

   Subject: Re: CVS commit: syssrc
Message-ID: <200104190439.AAA23855@multics.mit.edu>

$   Is there a reason not to print what is being skipped,
$   just like the warning for large memory map entries?

Nothing.

$   Shouldn't there be a documentation update indicating
$   what this warning message means if users encounter it?

I also think so. I attached next patch.
Any suggestion?
---
 Masanori Kanaoka	kanaoka@ann.hi-ho.ne.jp

Index: machdep.c
===================================================================
RCS file: /ftp/cvs/syssrc/sys/arch/i386/i386/machdep.c,v
retrieving revision 1.432
diff -u -r1.432 machdep.c
--- machdep.c	2001/04/18 05:44:10	1.432
+++ machdep.c	2001/04/19 08:35:36
@@ -1875,15 +1875,21 @@
 			seg_end = bim->entry[x].addr + bim->entry[x].size;
 
 			/*
 			 * XXX: avoid Compatibility Holes
 			 *           PC-compatible frame buffer 0xa0000-0xbffff
 			 *           adapter ROM space          0xc0000-0xdffff
 			 *           system BIOS space          0xe0000-0xfffff
 			 */
 			if (seg_start >= 0xa0000) {
 				if (seg_end <= 0xfffff) {
-					printf("WARNING: skipping "
-					     "Compatibility Holes...\n ");
+					printf("WARNING: Skip "
+					     "memory map entry: "
+					     "0x%qx-0x%qx "
+					     "to avoid Compatibitiy Holes!\n",
+					     seg_start, seg_end);
 					continue;
 				} else {
 					if (seg_start <= 0xfffff) {
@@ -1875,15 +1875,21 @@
 
 			/*
-			 * XXX: avoid Compatibility Holes
-			 *           PC-compatible frame buffer 0xa0000-0xbffff
-			 *           adapter ROM space          0xc0000-0xdffff
-			 *           system BIOS space          0xe0000-0xfffff
+			 *   avoid Compatibility Holes
+			 * XXX  Holes within memory space that allow access to be 
+			 * XXX directed to the PC-compatible frame buffer(0xa0000-0xbffff),
+			 * XXX to adapter ROM space(0xc0000-0xdffff), and to system BIOS
+			 * XXX space(0xe0000-0xfffff).
+			 * XXX  Some laptop(for example Toshiba Satellite 2550X) report
+			 * XXX this area and occurred problems,so we avoid this area.
 			 */
 			if (seg_start >= 0xa0000) {